@@ -7,6 +7,7 @@ extern crate gl;
 use self::gl::types::*;
 use crate::actor::Actor;
 use crate::actor::EventHandler;
+use crate::actor::Layout;
 
 pub struct Stage<'a> {
   width: u32,
@@ -37,6 +38,14 @@ impl<'a>  Stage<'a> {
     self.visible = visible;
   }
 
+  pub fn set_needs_layout(&mut self) {
+     self.stage_actor.set_needs_layout();
+  }
+
+  pub fn set_layout(&mut self, layout: Option<Box<dyn Layout + 'a>>) {
+    self.stage_actor.set_layout(layout);
+  }
+
   pub fn handle_input(&mut self, key: usize) {
      println!("stage key: {}", key);
 
@@ -58,4 +67,4 @@ impl<'a>  Stage<'a> {
 
     self.stage_actor.sub_actor_list.len() - 1
   }
-}
\ No newline at end of file
+}
